##  Configure the Architecture Executive Dashboard
The architecture executive dashboard is tailored for reporting to management.
To learn how to configure the detailed views for the architecture executive dashboard, see [Creating a View](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio97d3b35fe55840129601970f533e50bd__section_tyf_hmm_5fc). The following rationalization KPIs are available to be configured for the dashboard:
  * Total cost of ownership of applications
  * Application lifecycle TCO
  * Share of maintenance cost
  * Share of support cost
  * Share of licensing cost
  * Maintenance cost of applications
  * Support cost of applications
  * Licensing cost of applications


Some examples for visualizing the evolution of your rationalization initiative:
  * See the main KPIs and their trends at a glance.
![Architecture Executive Dashboard with KPIs for application rationalization like total cost of ownership of applications, Share of support, maintenance, and licensing cost](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3f92464df1b0417e95e99382041e32ee_HiRes.png)
  * Click on the card for Total cost of ownership of applications to discover what causes positive or negative trends of the total cost of ownership. Configure and filter a detailed view that surfaces the relevant data points for your IT strategy. For example, display only the business capabilities that are affected by the ongoing rationalization initiative.
![Details of total cost of ownership of applications on the architecture executive dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioc552b03603a64bd8b8444fc7550a6d18_HiRes.png)
  * Discover more details for changes of Share of maintenance cost, Share of support cost, or Share of licensing cost and understand the cause for changes. Configure and filter a detailed view that surfaces the relevant data points for your IT strategy.
![Details of share of support cost on the architecture executive dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9354fbf77c62405ca024c3ab52ebe3b1_HiRes.png)
